@@ -498,6 +498,10 @@ class AuthService:
         check()
         return make_call(auth_pb2_grpc.AuthServiceStub(channel).Signup, request)
 
+    def StartSignup(self, request):
+        check()
+        return make_call(auth_pb2_grpc.AuthServiceStub(channel).StartSignup, request)
+
     def ConfirmForgotPasswordRequest(self, **kwargs):
         return auth_pb2.ConfirmForgotPasswordRequest(**kwargs)
 
@@ -558,6 +562,12 @@ class AuthService:
     def SignupResponse(self, **kwargs):
         return auth_pb2.SignupResponse(**kwargs)
 
+    def StartSignupRequest(self, **kwargs):
+        return auth_pb2.StartSignupRequest(**kwargs)
+
+    def StartSignupResponse(self, **kwargs):
+        return auth_pb2.StartSignupResponse(**kwargs)
+
     def TokenResponse(self, **kwargs):
         return auth_pb2.TokenResponse(**kwargs)
 
